pub struct PathProxy<'p>(/* private fields */);Implementations
Sourceimpl<'p> PathProxy<'p>
impl<'p> PathProxy<'p>
Sourcepub async fn new<P>(conn: &Connection, path: P) -> Result<PathProxy<'p>>
pub async fn new<P>(conn: &Connection, path: P) -> Result<PathProxy<'p>>
Creates a new proxy with the given path, and the default destination.
Sourcepub fn builder(conn: &Connection) -> Builder<'p, Self>
pub fn builder(conn: &Connection) -> Builder<'p, Self>
Returns a customizable builder for this proxy.
Sourcepub fn into_inner(self) -> Proxy<'p>
pub fn into_inner(self) -> Proxy<'p>
Consumes self, returning the underlying zbus::Proxy.
Sourcepub fn inner_mut(&mut self) -> &mut Proxy<'p>
pub fn inner_mut(&mut self) -> &mut Proxy<'p>
The mutable reference to the underlying zbus::Proxy.
Sourcepub async fn directory_mode(&self) -> Result<u32>
pub async fn directory_mode(&self) -> Result<u32>
DirectoryMode property
Sourcepub fn cached_directory_mode(
&self,
) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>
pub fn cached_directory_mode( &self, ) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>
DirectoryMode property
Get the cached value of the DirectoryMode property, or None if the property is not cached.
Sourcepub async fn receive_directory_mode_changed(
&self,
) -> PropertyStream<'p, <Result<u32> as ResultAdapter>::Ok>
pub async fn receive_directory_mode_changed( &self, ) -> PropertyStream<'p, <Result<u32> as ResultAdapter>::Ok>
DirectoryMode property
Create a stream for the DirectoryMode property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub async fn make_directory(&self) -> Result<bool>
pub async fn make_directory(&self) -> Result<bool>
MakeDirectory property
Sourcepub fn cached_make_directory(
&self,
) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
pub fn cached_make_directory( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
MakeDirectory property
Get the cached value of the MakeDirectory property, or None if the property is not cached.
Sourcepub async fn receive_make_directory_changed(
&self,
) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
pub async fn receive_make_directory_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
MakeDirectory property
Create a stream for the MakeDirectory property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub fn cached_paths(
&self,
) -> Result<Option<<Result<Vec<PathWatch>> as ResultAdapter>::Ok>, <Result<Vec<PathWatch>> as ResultAdapter>::Err>
pub fn cached_paths( &self, ) -> Result<Option<<Result<Vec<PathWatch>> as ResultAdapter>::Ok>, <Result<Vec<PathWatch>> as ResultAdapter>::Err>
Paths property
Get the cached value of the Paths property, or None if the property is not cached.
Sourcepub async fn receive_paths_changed(
&self,
) -> PropertyStream<'p, <Result<Vec<PathWatch>> as ResultAdapter>::Ok>
pub async fn receive_paths_changed( &self, ) -> PropertyStream<'p, <Result<Vec<PathWatch>> as ResultAdapter>::Ok>
Paths property
Create a stream for the Paths property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub fn cached_result(
&self,
) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
pub fn cached_result( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
Result property
Get the cached value of the Result property, or None if the property is not cached.
Sourcepub async fn receive_result_changed(
&self,
) -> PropertyStream<'p, <Result<String> as ResultAdapter>::Ok>
pub async fn receive_result_changed( &self, ) -> PropertyStream<'p, <Result<String> as ResultAdapter>::Ok>
Result property
Create a stream for the Result property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub async fn trigger_limit_burst(&self) -> Result<u32>
pub async fn trigger_limit_burst(&self) -> Result<u32>
TriggerLimitBurst property
Sourcepub fn cached_trigger_limit_burst(
&self,
) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>
pub fn cached_trigger_limit_burst( &self, ) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>
TriggerLimitBurst property
Get the cached value of the TriggerLimitBurst property, or None if the property is not cached.
Sourcepub async fn receive_trigger_limit_burst_changed(
&self,
) -> PropertyStream<'p, <Result<u32> as ResultAdapter>::Ok>
pub async fn receive_trigger_limit_burst_changed( &self, ) -> PropertyStream<'p, <Result<u32> as ResultAdapter>::Ok>
TriggerLimitBurst property
Create a stream for the TriggerLimitBurst property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub async fn trigger_limit_interval_usec(&self) -> Result<u64>
pub async fn trigger_limit_interval_usec(&self) -> Result<u64>
TriggerLimitIntervalUSec property
Sourcepub fn cached_trigger_limit_interval_usec(
&self,
) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
pub fn cached_trigger_limit_interval_usec( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
TriggerLimitIntervalUSec property
Get the cached value of the TriggerLimitIntervalUSec property, or None if the property is not cached.
Sourcepub async fn receive_trigger_limit_interval_usec_changed(
&self,
) -> PropertyStream<'p, <Result<u64> as ResultAdapter>::Ok>
pub async fn receive_trigger_limit_interval_usec_changed( &self, ) -> PropertyStream<'p, <Result<u64> as ResultAdapter>::Ok>
TriggerLimitIntervalUSec property
Create a stream for the TriggerLimitIntervalUSec property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub fn cached_unit(
&self,
) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
pub fn cached_unit( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
Unit property
Get the cached value of the Unit property, or None if the property is not cached.
Sourcepub async fn receive_unit_changed(
&self,
) -> PropertyStream<'p, <Result<String> as ResultAdapter>::Ok>
pub async fn receive_unit_changed( &self, ) -> PropertyStream<'p, <Result<String> as ResultAdapter>::Ok>
Unit property
Create a stream for the Unit property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.